function result = test_template(Xtest, model, pars)
% function result = test_template(Xtest, model, pars)
%
% Template for writing test_* functions that evaluate a regression model on new data.
% Its sole purpose is to define a common interface for the various test_* functions;
% it does not in itself perform any useful function.
%
% See also: train_template, test_*, train_*
%
% INPUT:
%   Xtest     Nxd matrix of test inputs (N data points, d dimensions)
%   model     the model (e.g., weight vector)
%   pars      structure containing parameters of the regression method
%
% OUTPUT:
%   result    structure with the result of the regression
%             required fields:
%               .Ytest        Nx1 matrix: predicted outputs of the model,
%                             evaluated on test inputs
%             optional fields:
%               .loss         loss function of model on test inputs
%               .Ytestvar     Nx1 matrix: variances of outputs of the model,
%                             evaluated on test inputs
%               ...           ...
%
% Copyright (c) 2011-2011  Joris Mooij  [joris.mooij@tuebingen.mpg.de]
%               2011-2011  Jonas Peters [jonas.peters@tuebingen.mpg.de]
% All rights reserved.  See the file COPYING for license terms.

  help('test_template');

return
